@@ -22,7 +22,7 @@ from __future__ import absolute_import
 __doc__ = 'Generate distribution packages from PyPI'
 __docformat__ = 'restructuredtext en'
 __author__ = 'Sascha Peilicke <saschpe@gmx.de>'
-__version__ = '0.4.9'
+__version__ = '0.4.10'
 
 import argparse
 import datetime
@@ -49,7 +49,7 @@ import jinja2
 
 
 TEMPLATE_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'templates')  # absolute template path
-pypi = xmlrpclib.ServerProxy('http://python.org/pypi')                      # XML RPC connection to PyPI
+pypi = xmlrpclib.ServerProxy('https://pypi.python.org/pypi')                      # XML RPC connection to PyPI
 env = jinja2.Environment(loader=jinja2.FileSystemLoader(TEMPLATE_DIR))      # Jinja2 template environment
 env.filters['parenthesize_version'] = \
     lambda s: re.sub('([=<>]+)(.+)', r' (\1 \2)', s)
@@ -58,7 +58,7 @@ SPDX_LICENSES_FILE = os.path.join(os.path.dirname(os.path.abspath(__file__)), 's
 SDPX_LICENSES = pickle.load(open(SPDX_LICENSES_FILE, 'rb'))
 
 
-def list(args):
+def list(args=None):
     print('listing all PyPI packages...')
     for package in pypi.list_packages():                                    # nothing fancy
         print(package)
